#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/device-mapper-update.sh - paramater update script
#
# Creation   :  2013-05-23 hbfl
# Last update:  $Id: device-mapper-update.sh 103071 2023-05-23 16:23:29Z hbfl $
#
# Copyright (c) 2019-2023 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=device-mapper

# include configlib
. /var/install/include/configlib

VERSION=3.4.1

# ---------------------------------------------------------------------------
# set default values for configuration
# ---------------------------------------------------------------------------
get_defaults()
{
    START_DEVICE_MAPPER='no'

    DEVICE_MAPPER_EVENT='no'
}   

# ---------------------------------------------------------------------------
# read old configuration and rename old variables
# ---------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} '2023-05-23' 'hbfl'
    # -----------------------------------------------------------------------
    echo "# LVM2-device-mapper VERSION ${VERSION}"

    # -----------------------------------------------------------------------
    printgroup 'Basic configuration'
    # -----------------------------------------------------------------------

    printvar 'START_DEVICE_MAPPER'                 
    printcomment            'Use yes or no'
    echo

    printvar 'DEVICE_MAPPER_EVENT'
    printcomment            'Use yes or no'

    # -----------------------------------------------------------------------
    printend
    # -----------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}
# ---------------------------------------------------------------------------
# create check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} '2023-05-23' 'hbfl' >/etc/check.d/${package_name}
cat >>/etc/check.d/${package_name} <<EOF
# Variable           OPT_VARIABLE         VARIABLE_N   VALUE
START_DEVICE_MAPPER  -                    -            YESNO

DEVICE_MAPPER_EVENT  START_DEVICE_MAPPER  -            YESNO
EOF

   # Set rights for check.d file
   chmod 0600 /etc/check.d/${package_name}
   chown root /etc/check.d/${package_name}
}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
main()
{
    get_defaults

    # write default config file
    make_config_file /etc/default.d/${package_name}
  
    # update from old version
    rename_old_variables

    # write new config file
    make_config_file /etc/config.d/${package_name}

    # write check.d file
    make_check_file

    exit 0
}

# ---------------------------------------------------------------------------
# call function main
# ---------------------------------------------------------------------------
main "${@}"

# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
